"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Class to contain default z/OSMF headers
 * @export
 * @class ZosmfHeaders
 */
class ZosmfHeaders {
}
/**
 * lrecl header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_INTRDR_LRECL = "X-IBM-Intrdr-Lrecl";
/**
 * recfm header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_INTRDR_RECFM = "X-IBM-Intrdr-Recfm";
/**
 * job class header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_INTRDR_CLASS_A = { "X-IBM-Intrdr-Class": "A" };
/**
 * fixed recfm header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_INTRDR_RECFM_F = { "X-IBM-Intrdr-Recfm": "F" };
/**
 * 80 lrecl header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_INTRDR_LRECL_80 = { "X-IBM-Intrdr-Lrecl": "80" };
/**
 * 256 lrecl header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_INTRDR_LRECL_256 = { "X-IBM-Intrdr-Lrecl": "256" };
/**
 * text type header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_INTRDR_MODE_TEXT = { "X-IBM-Intrdr-Mode": "TEXT" };
/**
 * n/a header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_NOTIFICATION_URL = { "X-IBM-Notification-URL": "" };
/**
 * base header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_ATTRIBUTES_BASE = { "X-IBM-Attributes": "base" };
/**
 * If you use this header, delete job API will be asynchronous.
 * This is the default setting, so using this header is not really necessary unless you want to be explicit.
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_JOB_MODIFY_VERSION_1 = { "X-IBM-Job-Modify-Version": "1.0" };
/**
 * If you use this header, delete job API will be synchronous.
 * But using it may cause problems for some users depending on their maintenance level and configuration.
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_JOB_MODIFY_VERSION_2 = { "X-IBM-Job-Modify-Version": "2.0" };
/**
 * security header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_CSRF_ZOSMF_HEADER = { "X-CSRF-ZOSMF-HEADER": true }; // "the value does not matter"
/**
 * binary transfer header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_BINARY = { "X-IBM-Data-Type": "binary" };
/**
 * binary by record header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_BINARY_BY_RECORD = { "X-IBM-Data-Type": "record" };
/**
 * text transfer header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_TEXT = { "X-IBM-Data-Type": "text" };
/**
 * octet stream header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.OCTET_STREAM = { "Content-Type": "application/octet-stream" };
/**
 * plain text header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.TEXT_PLAIN = { "Content-Type": "text/plain" };
/**
 * This header value specifies the maximum number of items to return.
 * To request that all items be returned, set this header to 0. If you omit this header, or specify an incorrect value,
 * up to 1000 items are returned by default.
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_MAX_ITEMS = { "X-IBM-Max-Items": "0" };
/**
 * data set migrated recall headers
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_MIGRATED_RECALL_WAIT = { "X-IBM-Migrated-Reacall": "wait" };
ZosmfHeaders.X_IBM_MIGRATED_RECALL_NO_WAIT = { "X-IBM-Migrated-Reacall": "nowait" };
ZosmfHeaders.X_IBM_MIGRATED_RECALL_ERROR = { "X-IBM-Migrated-Reacall": "error" };
/**
 * Check ETag on read header
 * Returns HTTP 304 if not modified
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.IF_NONE_MATCH = "If-None-Match";
/**
 * Check ETag on write header
 * Returns HTTP 412 if not matched
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.IF_MATCH = "If-Match";
/**
 * Force ETag return header
 * @static
 * @memberof ZosmfHeaders
 */
ZosmfHeaders.X_IBM_RETURN_ETAG = { "X-IBM-Return-Etag": "true" };
exports.ZosmfHeaders = ZosmfHeaders;
//# sourceMappingURL=ZosmfHeaders.js.map