import { IMessageDefinition } from "@brightside/imperative";
/**
 * Constants for workflow related APIs.
 * @export
 * @class WorkflowConstants
 */
export declare class WorkflowConstants {
    /**
     * URI base for workflow API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly RESOURCE: string;
    /**
     * URI base for workflows API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly WORKFLOW_DEFINITION: string;
    /**
     * URI base for workflows API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly WORKFLOW_RESOURCE: string;
    /**
     * URI base for workflows API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly ARCH_WORKFLOW_RESOURCE: string;
    /**
     * URI base for starting workflow API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly START_WORKFLOW: string;
    /**
     * URI base for archiving workflow API
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly ARCHIVE_WORKFLOW: string;
    /**
     * URI base for canceling workflow API.
     *
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly CANCEL_WORKFLOW: string;
    /**
     * URI base for list workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly LIST_WORKFLOWS: string;
    /**
     * URI base for filter workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly category: string;
    /**
     * URI base for filter workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly system: string;
    /**
     * URI base for filter workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly owner: string;
    /**
     * URI base for filter workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly vendor: string;
    /**
     * URI base for filter workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly statusName: string;
    /**
     * URI base for filter workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly workflowKey: string;
    /**
     * URI base for filter workflows from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly workflowName: string;
    /**
     * URI base for filtering workflow by name API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly WF_NAME: string;
    /**
     * Version of the z/OSMF
     * @static
     * @type {string}
     * @memberOf WorkflowConstants
     */
    static readonly ZOSMF_VERSION: string;
    /**
     * URI base for returnData for workflow properties from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly returnData: string;
    /**
     * URI base for steps for workflow properties from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly steps: string;
    /**
     * URI base for variables for workflow properties from registry API.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly variables: string;
    /**
     * URI base for filePath for workflow definition.
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly filePath: string;
    /**
     * Default path for uploading temporary files
     * @static
     * @type {string}
     * @memberof WorkflowConstants
     */
    static readonly tempPath: string;
}
/**
 * Error message that no session was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noSession: IMessageDefinition;
/**
 * Error message that no z/OSMF version parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const nozOSMFVersion: IMessageDefinition;
/**
 * Error message that no workflow key string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noWorkflowKey: IMessageDefinition;
/**
 * Error message that workflow key that was supplied does not exist.
 * IZUWF5001W: The workflow key "workflowkey" was not found.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const WrongWorkflowKey: IMessageDefinition;
/**
 * Error message that no steps parameter was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noSteps: IMessageDefinition;
/**
 * Error message that no variables parameter was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noVariables: IMessageDefinition;
/**
 * Error message that no workflow definition file parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noWorkflowDefinitionFile: IMessageDefinition;
/**
 * Error message that no workflow name parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noWorkflowName: IMessageDefinition;
/**
 * Error message that no system name parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noSystemName: IMessageDefinition;
/**
 * Error message that no system name parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const wrongString: IMessageDefinition;
/**
 * Error message that no owner parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
export declare const noOwner: IMessageDefinition;
export declare const wrongOwner: IMessageDefinition;
