/// <reference types="node" />
/**
 * Common IO utilities
 */
export declare class ZosFilesUtils {
    /**
     * Data set name qualifier separator
     * @type {string}
     */
    static readonly DSN_SEP: string;
    /**
     * Default file extension
     * @type {string}
     */
    static readonly DEFAULT_FILE_EXTENSION: string;
    static readonly MAX_MEMBER_LENGTH: number;
    /**
     * Break up a dataset name of either:
     *  USER.WORK.JCL(TEMPLATE) to user/work/jcl/template
     * Or:
     *  USER.WORK.PS to user/work/ps
     * @param  {string} dataSet - data set to break up into folders
     */
    static getDirsFromDataSet(dataSet: string): string;
    /**
     * Get fullpath name from input path.
     * @param {string} inputPath - input path
     * @return {string} full path version of the input path
     */
    static getFullPath(inputPath: string): string;
    /**
     * Return an array contain the list of all files in the input path. It does not trevor to
     * directory in the input path.
     * @param {string}  inputPath input path to gather file list
     * @param {boolean} [inFullPathFormat=true] is the return file path in full path mode flag
     * @param {boolean} [isIgnoreHidden=true] is listing hidden files flag
     * @return {string[]} Array of all files finds in path
     */
    static getFileListFromPath(inputPath: string, inFullPathFormat?: boolean, isIgnoreHidden?: boolean): string[];
    /**
     * Generate member name from input string base on IBM specification
     * @param {string} fileName input name used to generate member name with
     * @return {string} generated member name
     */
    static generateMemberName(fileName: string): string;
    /**
     * Check if the input data set name contain masking characters
     * @param {string} dataSetName input data set name to be checked
     * @return {boolean} status if data set name contain masking characters
     */
    static isDataSetNameContainMasking(dataSetName: string): boolean;
    /**
     * Normalize all Windows newline to Unix newline
     * @param {Buffer} buffer data to convert
     * @return {Buffer} converted data
     */
    static normalizeNewline(buffer: Buffer): Buffer;
    /**
     * Format USS filepaths in the way that the APIs expect (no leading /)
     * @param {string} usspath - the path to format
     */
    static formatUnixFilepath(usspath: string): string;
    static sanitizeUssPathForRestCall(ussPath: string): string;
}
