/**
 * This class is the main engine for the Config Management Facility. The
 * underlying class should be treated as a singleton and should be accessed
 * via ConfigManagementFacility.instance.
 */
export declare class ConfigManagementFacility {
    /**
     * This is the variable that stores the specific instance of the CMF. Defined
     * as static so that it can be accessed from anywhere.
     *
     * @private
     * @type {ConfigManagementFacility}
     */
    private static mInstance;
    /**
     * Used for internal imperative logging.
     *
     * @private
     * @type {Logger}
     */
    private impLogger;
    /**
     * Gets a single instance of the CMF. On the first call of
     * ConfigManagementFacility.instance, a new CMF is initialized and returned.
     * Every subsequent call will use the one that was first created.
     *
     * @returns {ConfigManagementFacility} - The newly initialized CMF object.
     */
    static readonly instance: ConfigManagementFacility;
    /**
     * Initialize the CMF. Must be called to enable the various commands provided
     * by the facility.
     */
    init(): void;
}
