"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../../../../logger/");
const error_1 = require("../../../../../error");
const AppSettings_1 = require("../../../../../settings/src/AppSettings");
/**
 * The command group handler for cli configuration settings reset.
 *
 */
class ResetHandler {
    constructor() {
        /**
         * A logger for this class
         *
         * @private
         * @type {Logger}
         */
        this.log = logger_1.Logger.getImperativeLogger();
    }
    /**
     * Process the command and input.
     *
     * @param {IHandlerParameters} params Parameters supplied by yargs
     *
     * @throws {ImperativeError}
     */
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            switch (params.arguments.configName) {
                case ResetHandler.RESET_CREGENTIAL_MANAGER:
                    yield this.resetCredentialManager();
                    break;
                default:
                    throw new error_1.ImperativeError({
                        msg: "The setting you tried to change does not exist.",
                        additionalDetails: JSON.stringify(params)
                    });
            }
        });
    }
    /**
     * Reset the credential manager to default - false.
     *
     * @throws {ImperativeError}
     */
    resetCredentialManager() {
        return __awaiter(this, void 0, void 0, function* () {
            yield AppSettings_1.AppSettings.instance.setNewOverride("CredentialManager", false);
        });
    }
}
/*
 * A variable with which to compare the input of the reset command for the switch
 */
ResetHandler.RESET_CREGENTIAL_MANAGER = "credential-manager";
exports.default = ResetHandler;
//# sourceMappingURL=reset.handler.js.map