"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const zowe = require("@brightside/core");
const Profiles_1 = require("./Profiles");
class SpoolProvider {
    constructor() {
        this.mOnDidChange = new vscode.EventEmitter();
    }
    provideTextDocumentContent(uri) {
        const [sessionName, spool] = decodeJobFile(uri);
        const zosMfProfile = Profiles_1.Profiles.getInstance().loadNamedProfile(sessionName);
        const session = zowe.ZosmfSession.createBasicZosmfSession(zosMfProfile.profile);
        return zowe.GetJobs.getSpoolContentById(session, spool.jobname, spool.jobid, spool.id);
    }
    dispose() {
        this.mOnDidChange.dispose();
    }
}
exports.default = SpoolProvider;
SpoolProvider.scheme = "zosspool";
/**
 * Encode the information needed to get the Spool content.
 *
 * @param session The name of the Zowe profile to use to get the Spool Content
 * @param spool The IJobFile to get the spool content for.
 */
function encodeJobFile(session, spool) {
    const query = JSON.stringify([session, spool]);
    return vscode.Uri.parse(`${SpoolProvider.scheme}:${spool.jobname}.${spool.jobid}.${spool.ddname}?${query}`);
}
exports.encodeJobFile = encodeJobFile;
/**
 * Decode the information needed to get the Spool content.
 *
 * @param uri The URI passed to TextDocumentContentProvider
 */
function decodeJobFile(uri) {
    const [session, spool] = JSON.parse(uri.query);
    return [session, spool];
}
exports.decodeJobFile = decodeJobFile;

//# sourceMappingURL=SpoolProvider.js.map
